==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/change/bean/ChangeconsdrawbudgetEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工预算图变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_consdrawbudget")
public class ChangeconsdrawbudgetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="consdrawbudget_id")
    private java.lang.Long consdrawbudgetId; // 施工图预算id
    @TableField(value="con_draw_budget_total")
    private java.math.BigDecimal conDrawBudgetTotal; // 施工图预算合计
    @TableField(value="is_open_control")
    private java.lang.Integer isOpenControl; // 是否开启控制:0 否，1:是
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="provisional_estimate_total")
    private java.math.BigDecimal provisionalEstimateTotal; // 暂估价合计
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changeconsdrawbudgetdetailService",pidName = "changeMid")
    private List<ChangeconsdrawbudgetdetailEntity> changeconsdrawbudgetdetailEntities = new ArrayList<>(); // 施工图预算变更子表
    

    /**
     * 施工图预算id
     */
    public java.lang.Long getConsdrawbudgetId() {
        return consdrawbudgetId;
    }

    /**
     * 施工图预算id
     */
    public void setConsdrawbudgetId(java.lang.Long consdrawbudgetId) {
        this.consdrawbudgetId = consdrawbudgetId;
    }
    /**
     * 施工图预算合计
     */
    public java.math.BigDecimal getConDrawBudgetTotal() {
        return conDrawBudgetTotal;
    }

    /**
     * 施工图预算合计
     */
    public void setConDrawBudgetTotal(java.math.BigDecimal conDrawBudgetTotal) {
        this.conDrawBudgetTotal = conDrawBudgetTotal;
    }
    /**
     * 是否开启控制:0 否，1:是
     */
    public java.lang.Integer getIsOpenControl() {
        return isOpenControl;
    }

    /**
     * 是否开启控制:0 否，1:是
     */
    public void setIsOpenControl(java.lang.Integer isOpenControl) {
        this.isOpenControl = isOpenControl;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 暂估价合计
     */
    public java.math.BigDecimal getProvisionalEstimateTotal() {
        return provisionalEstimateTotal;
    }

    /**
     * 暂估价合计
     */
    public void setProvisionalEstimateTotal(java.math.BigDecimal provisionalEstimateTotal) {
        this.provisionalEstimateTotal = provisionalEstimateTotal;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    
    /**
     * 施工图预算变更子表
     */
    public List<ChangeconsdrawbudgetdetailEntity> getChangeconsdrawbudgetdetailEntities() {
        return changeconsdrawbudgetdetailEntities;
    }

    /**
     * 施工图预算变更子表
     */
    public void setChangeconsdrawbudgetdetailEntities(List<ChangeconsdrawbudgetdetailEntity> changeconsdrawbudgetdetailEntities) {
        this.changeconsdrawbudgetdetailEntities = changeconsdrawbudgetdetailEntities;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220407.084509-69-sources.jar: com/ejianc/business/change/bean/ChangeconsdrawbudgetEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工预算图变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_consdrawbudget")
public class ChangeconsdrawbudgetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="consdrawbudget_id")
    private java.lang.Long consdrawbudgetId; // 施工图预算id
    @TableField(value="con_draw_budget_total")
    private java.math.BigDecimal conDrawBudgetTotal; // 施工图预算合计
    @TableField(value="is_open_control")
    private java.lang.Integer isOpenControl; // 是否开启控制:0 否，1:是
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="provisional_estimate_total")
    private java.math.BigDecimal provisionalEstimateTotal; // 暂估价合计
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changeconsdrawbudgetdetailService",pidName = "changeMid")
    private List<ChangeconsdrawbudgetdetailEntity> consdrawbudgetdetailEntities = new ArrayList<>(); // 施工图预算变更子表
    

    /**
     * 施工图预算id
     */
    public java.lang.Long getConsdrawbudgetId() {
        return consdrawbudgetId;
    }

    /**
     * 施工图预算id
     */
    public void setConsdrawbudgetId(java.lang.Long consdrawbudgetId) {
        this.consdrawbudgetId = consdrawbudgetId;
    }
    /**
     * 施工图预算合计
     */
    public java.math.BigDecimal getConDrawBudgetTotal() {
        return conDrawBudgetTotal;
    }

    /**
     * 施工图预算合计
     */
    public void setConDrawBudgetTotal(java.math.BigDecimal conDrawBudgetTotal) {
        this.conDrawBudgetTotal = conDrawBudgetTotal;
    }
    /**
     * 是否开启控制:0 否，1:是
     */
    public java.lang.Integer getIsOpenControl() {
        return isOpenControl;
    }

    /**
     * 是否开启控制:0 否，1:是
     */
    public void setIsOpenControl(java.lang.Integer isOpenControl) {
        this.isOpenControl = isOpenControl;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 暂估价合计
     */
    public java.math.BigDecimal getProvisionalEstimateTotal() {
        return provisionalEstimateTotal;
    }

    /**
     * 暂估价合计
     */
    public void setProvisionalEstimateTotal(java.math.BigDecimal provisionalEstimateTotal) {
        this.provisionalEstimateTotal = provisionalEstimateTotal;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }

    public List<ChangeconsdrawbudgetdetailEntity> getConsdrawbudgetdetailEntities() {
        return consdrawbudgetdetailEntities;
    }

    public void setConsdrawbudgetdetailEntities(List<ChangeconsdrawbudgetdetailEntity> consdrawbudgetdetailEntities) {
        this.consdrawbudgetdetailEntities = consdrawbudgetdetailEntities;
    }
}
